# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

- Nothing yet

## [0.0.6]

- Clarify error message

## [0.0.5]

- Make missing feedback code error friendlier

## [0.0.4]

- Fix bug involving relative paths
- Switch example AutoHotkey scripts to Windows Terminal to leverage `rich` formatting

## [0.0.3]

- Make headings flexible
- Search current working directory for DOCX files by default
- Use `rich` for prettier tracebacks
- Pin dependencies

## [0.0.2]

- Implement CLI
- Implement AutoHotkey scripts for common actions
- Expect `docx_dir` to be supplied in config file only
- Implement example within the package

## [0.0.1]

- Migrate `grade-me380`

[Unreleased]: https://github.com/blakeNaccarato/gradedoc/compare/0.0.6...HEAD
[0.0.6]: https://github.com/blakeNaccarato/gradedoc/compare/0.0.4...0.0.6
[0.0.5]: https://github.com/blakeNaccarato/gradedoc/compare/0.0.4...0.0.5
[0.0.4]: https://github.com/blakeNaccarato/gradedoc/compare/0.0.3...0.0.4
[0.0.3]: https://github.com/blakeNaccarato/gradedoc/compare/0.0.2...0.0.3
[0.0.2]: https://github.com/blakeNaccarato/gradedoc/compare/0.0.1...0.0.2
[0.0.1]: https://github.com/blakeNaccarato/gradedoc/releases/tag/0.0.1
